pub use crate::error::DecodeError;
pub use crate::opcode::{Instruction, Opcode};
pub use crate::{decode, decode_py27};
